Struct unicode_prettytable::HeaderBuilder [−][src]
Builder for Header.
Implementations
impl HeaderBuilder[src]
pub fn double_bar(&mut self, value: bool) -> &mut Self[src]
Whether to use double bar Unicode characters surrounding the header
pub fn centered_text(&mut self, value: bool) -> &mut Self[src]
Whether to center the header text within each column
pub fn build(&self) -> Result<Header, String>[src]